#!/usr/bin/env python
# This file is part of AutoInteractive.

# AutoInteractive is free software: you can redistribute it and/or modify
# it under the terms of the Python 2.6.2 license

# AutoInteractive is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

# To read the license please read:
# http://www.python.org/download/releases/2.6.2/license/

# Author: Fabian Ezequiel Gallina <fgallina at from-the-cloud dot com>

# AutoInteractive allows to execute a python file line by line as if
# you were typing it on the python interactive shell, it is based on
# the official python InteractiveConsole class
import sys
import os
from code import InteractiveConsole
from getch import getch

class AutoInteractiveShell(InteractiveConsole):

    def __init__(self, locals=None, filename="<console>", path=""):
        """See code.InteractiveConsole.__init__"""
        InteractiveConsole.__init__(self, locals=None, filename="<console>");
        self.path = path;

    def interact(self, banner=None):
        """Emulate an automatic interactive Python console.

        The optional banner argument specify the banner to print
        before the first interaction; by default it prints a banner
        similar to the one printed by the real Python interpreter,
        followed by the current class name in parentheses (so as not
        to confuse this with the real interpreter -- since it's so
        close!).

        This interact method overrides the one defined in
        code.InteractiveConsole, the code is very much the same but
        instead of getting the code from the stdin it reads it from
        the python file passed as parameter.

        """
        try:
            sys.ps1
        except AttributeError:
            sys.ps1 = ">>> "
        try:
            sys.ps2
        except AttributeError:
            sys.ps2 = "... "
        cprt = 'Type "help", "copyright", "credits" or "license" for more information.'
        if banner is None:
            self.write("Python %s on %s\n%s\n(%s)\n" %
                       (sys.version, sys.platform, cprt,
                        self.__class__.__name__))
        else:
            self.write("%s\n" % str(banner))
        more = 0
        try:
            pythonfile = open(self.path, 'r')
        except IOError:
            print "The file %s does not exists" % self.path
            exit()
        self.push("from autointeractive import AutoInteractiveShell")
        for line in pythonfile.xreadlines():
            try:
                if more:
                    prompt = sys.ps2
                else:
                    prompt = sys.ps1
                try:
                    line = self.raw_input(line, prompt)
                    # Can be None if sys.stdin was redefined
                    encoding = getattr(sys.stdin, "encoding", None)
                    if encoding and not isinstance(line, unicode):
                        line = line.decode(encoding)
                except EOFError:
                    self.write("\n")
                    break
                else:
                    more = self.push(line)
            except KeyboardInterrupt:
                self.write("\nKeyboardInterrupt\n")
                self.resetbuffer()
                more = 0

    def raw_input(self, contents, prompt=""):
        if(contents != '\n'):
            print prompt + contents[:-1]
            key = None
            while repr(key) not in (repr('\r'), repr('\x03')):
                key = getch()
                if(repr(key) == repr('\x03')):
                    exit()
        return contents[:-1]


    @staticmethod
    def clear():
        if os.name == 'posix':
            os.system('clear')
        elif os.name in ('nt', 'dos', 'ce'):
            os.system('CLS')
        else:
            print "\n" * 60



if __name__ == '__main__':
    from optparse import OptionParser
    parser = OptionParser()
    (options, args) = parser.parse_args()
    try:
        path = args[0]
    except IndexError:
        print "you must specify the file path"
        exit()
    shell = AutoInteractiveShell(path=path)
    shell.interact("Auto Interactive console started")
